<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake;

/**
 * Root file path
 */
define('PANCAKE_ROOT', __DIR__ . '/');

/**
 * Class autoloader
 * 
 * @package Katla
 */
class Autoloader
{
	/**
	 * Directory from which to load files
	 * 
	 * @var string
	 */
	protected static $_directory = __DIR__;
	
	/**
	 * Local namespace
	 * 
	 * @var string
	 */
	protected static $_namespace = __NAMESPACE__;
	
	/**
	 * Searches for and includes the appropriate class file
	 * 
	 * @param string $className
	 */
	public static function load($className)
	{
		// Fetch the directory and the namespace from the child class
		$autoloaderClass = get_called_class();
		$directory = $autoloaderClass::$_directory;
		$namespace = $autoloaderClass::$_namespace;
		
		// Formulate a file path based on the namespace
		$filePath = preg_replace('#^\\\?' . $namespace . '#', null, $className);
		$filePath = str_replace('\\', '/', $filePath);
		$filePath = $directory . $filePath . '.php';
		
		// Include the file if it is readable
		if (is_readable($filePath))
		{
			include $filePath;
		}
	}
}

// Register the autoloader
spl_autoload_register(__NAMESPACE__ . '\Autoloader::load');