<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

use Pancake\Settings;
use Pancake\Validator\IsDate;

/**
 * Date calendar <input> field
 * 
 * Examples:
 * <code>
 * $form->dateCalendar('birthday');
 * $form->dateCalendar('birthday', array('required' => false));
 * </code>
 * 
 * Field-specific properties:
 * - <b>date_format:</b> OPTIONAL Date format for formatted value (default: {@link \Pancake\Settings\Dates::DATE_FORMAT})
 * 
 * @package    Pancake
 * @subpackage Fields
 */
class DateCalendar extends InputText
{
	public static $methodName = 'dateCalendar';
	protected $_paragraphClasses = array(
		'calendar',
		'date',
		'field',
		'text'
	);
	
	// Return date format
	protected $_validProperties = array(
		'date_format' => Settings\Dates::DATE_FORMAT
	);
	
	/**
	 * Adds default date validation
	 */
	protected function _init()
	{
		parent::_init();
		$this->_addValidation('IsDate');
	}
	
	/**
	 * Allows value to be set via a UNIX timestamp
	 * 
	 * @param  mixed $value OPTIONAL
	 * @return mixed
	 */
	protected function _value($value = null)
	{
		// Set the value of the date inputs
		if ($value !== null)
		{
			// Set <input> attribute
			$this->attribute('value', (string) $value);
			
			// Assume an integer is a valid Unix timestamp
			if (!is_int($value))
			{
				$value = strtotime($value);
			}
			
			// Store the timestamp centrally
			$this->_value = $value;
		}
		
		return (!empty($this->_value)) ? date(IsDate::DATE_FORMAT, $this->_value) : null;
	}
	
	/**
	 * Returns a formatted date
	 * 
	 * @return string
	 */
	protected function _formattedValue()
	{
		return (!empty($this->_value)) ? date($this->property('date_format'), $this->_value) : null;
	}
}