<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

use Pancake\Exception;
use Pancake\Helper;

/**
 * Generic <input> field
 * 
 * Examples:
 * <code>
 * $form->input('foobar', 'text');
 * $form->input('yes_no', 'checkbox');
 * $form->input('yes_no', 'checkbox', array('label' => 'Yes or No?'));
 * </code>
 * 
 * @package    Pancake
 * @subpackage Fields
 */
class Input extends Field
{
	public static $methodName = 'input';
	protected $_paragraphClasses = array(
		'field'
	);
	
	// Attributes and parameters
	protected $_validAttributes = array(
		'accept' => null,
		'alt' => null,
		'checked' => null,
		'disabled' => null,
		'maxlength' => null,
		'readonly' => null,
		'size' => null,
		'src' => null,
		'type' => null,
		'usemap' => null,
		'value' => null
	);
	protected $_requiredParameters = array(
		'type'
	);
	
	/**
	 * Valid input types
	 * 
	 * @var array
	 */
	protected $_validTypes = array(
		'button',
		'checkbox',
		'file',
		'hidden',
		'image',
		'password',
		'radio',
		'reset',
		'submit',
		'text'
	);
	
	/**
	 * Checks that the <input> type is valid
	 * 
	 * @throws \Pancake\Exception\ValueError When the input type is not valid
	 */
	protected function _init()
	{
		if (!in_array($this->attribute('type'), $this->_validTypes))
		{
			throw new Exception\ValueError('"' . $this->attribute('type') . '" is not a valid <input> type.');
		}
	}
	
	/**
	 * @return string
	 */
	public function output()
	{
		return '<input' . Helper\Attributes::process($this->_attributes) . ' />';
	}
	
	/**
	 * Sets the value attribute
	 * 
	 * @param  string $value OPTIONAL
	 * @return string
	 */
	protected function _value($value = null)
	{
		if ($value !== null)
		{
			$this->attribute('value', (string) $value);
		}
		
		return parent::_value($value);
	}
}