<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

/**
 * Checkbox <input> field
 * 
 * Examples:
 * <code>
 * $form->checkbox('foobar');
 * $form->checkbox('foobar', 'checkbox', array('label' => 'Yes or No?'));
 * </code>
 * 
 * @package    Pancake
 * @subpackage Fields
 */
class InputCheckbox extends Input
{
	public static $methodName = 'checkbox';
	protected $_paragraphClasses = array(
		'field',
		'checkbox'
	);
	
	// Standardise checkbox values to "yes" for easier processing
	protected $_attributes = array(
		'type' => 'checkbox',
		'value' => 'yes'
	);
	
	// Checkboxes are usually not required and have the label after
	protected $_properties = array(
		'label_first' => false,
		'required' => false,
		'show_if_optional' => false
	);
	
	// Default value to false
	protected $_value = false;
	
	/**
	 * Adds default checkbox validation
	 */
	protected function _init()
	{
		$this->_addValidation('isCheckbox');
	}
	
	/**
	 * Processes the value
	 * 
	 * Ensures the stored value is a boolean and the "checked"
	 * attribute is properly set, always returning a boolean
	 * 
	 * @param  string|boolean $value OPTIONAL
	 * @return boolean
	 */
	protected function _value($value = null)
	{
		if ($value !== null)
		{
			if ($value === true || $value == $this->attribute('value'))
			{
				$this->_value = true;
				$this->attribute('checked', 'checked');
			}
			else
			{
				$this->_value = false;
				$this->attribute('checked', '');
			}
		}
		
		return $this->_value;
	}
	
	/**
	 * Returns "yes" or "no"
	 * 
	 * @return string
	 */
	protected function _formattedValue()
	{
		return ($this->value) ? 'Yes' : 'No';
	}
}