<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

/**
 * Checkbox <input> list field
 * 
 * Examples:
 * <code>
 * $form->checkboxList('numbers', array('one', 'two', 'three));
 * $form->checkboxList('numbers', array(array('one', array('help_text' => 'Uno')), 'two', 'three));
 * $form->checkboxList('numbers', array('one', 'two', 'three), array('label_element' => 'h4'));
 * </code>
 * 
 * Field-specific properties:
 * - <b>container:</b>     OPTIONAL Tag for the group container (defaults to "<div>")
 * - <b>label_element:</b> OPTIONAL Tag for the group label (defaults to "<h3>")
 * - <b>options:</b>       REQUIRED List options
 * 
 * @package    Pancake
 * @subpackage Fields
 * @uses       \Pancake\Field\ListCheckboxesOption
 */
class ListCheckboxes extends FieldList
{
	public static $methodName = 'checkboxList';
	protected $_paragraphClasses = array(
		'checkbox-list',
		'field',
		'list'
	);
	
	// Checkbox list settings
	protected $_optionClass = '\Pancake\Field\ListCheckboxesOption';
	protected $_allowMultiples = true;
	
	// Display group in a <div> with a pseudo label
	protected $_validProperties = array(
		'options' => array(),
		'label_element' => 'h3'
	);
	protected $_properties = array(
		'container' => 'div'
	);
	
	/**
	 * Encases the output in an unordered list
	 * 
	 * @return string
	 */
	public function output()
	{
		return '<ul>' . parent::output() . '</ul>';
	}
	
	/**
	 * Creates an "other" field
	 * 
	 * @param  string $name
	 * @param  string $parentName
	 * @param  array  $parameters
	 * @return \Pancake\Field\ListCheckboxesOption
	 */
	protected function _other($name, $parentName, $parameters)
	{
		$name = 'other'; // Standardise the name
		$parameters['other'] = true;
		
		return new $this->_optionClass($name, $parentName, $parameters);
	}
}