<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

use Pancake\Settings;

/**
 * Checkbox <input> list field option
 * 
 * @package    Pancake
 * @subpackage Fields
 * @see        \Pancake\Field\ListCheckboxes
 */
class ListCheckboxesOption extends InputCheckbox
{
	// Disable user creation of field
	public static $methodName = null;
	
	protected $_properties = array(
		// Make each option a list item
		'container' => 'li',
		
		// Default properties from InputCheckbox
		'label_first' => false,
		'required' => false,
		'show_if_optional' => false
	);
	
	// Require the parent name property
	// Mark if the field contains an "other" text box
	protected $_validProperties = array(
		'other' => false,
		'parent_name' => null
	);
	protected $_requiredParameters = array(
		'parent_name'
	);
	
	/**
	 * The "other" field
	 * 
	 * @var \Pancake\Field\InputText
	 */
	protected $_other;
	
	/**
	 * Processes the name and value attributes and sets up the "other" field
	 */
	protected function _init()
	{
		// The name attribute has to match the other items in the list, whilst
		// the value should correspond to the specific option.
		$this->attribute('name', $this->property('parent_name'));
		$this->attribute('value', $this->name);
		
		if ($this->property('other') === true)
		{
			// Hide the option label if an "other" field
			$this->property('show_label', false);
			
			// Create the other field
			$this->_other = new InputText(
				str_replace(Settings\Fields::ID_PREFIX, null, $this->id) . '_text',
				array(
					'label' => 'Other:',
					'paragraph' => false
				)
			);
		}
	}
	
	/**
	 * @return string
	 */
	public function output()
	{
		$output = parent::output();
		
		// Append the "other" field
		if ($this->property('other') === true)
		{
			$output .= $this->_other->__toString();
		}
		
		return $output;
	}
	
	/**
	 * Returns an ID that matches the parent name
	 * 
	 * @return string
	 */
	protected function _id()
	{
		return Settings\Fields::ID_PREFIX . str_replace('[]', null, $this->property('parent_name')) . '_' . $this->name;
	}
	
	/**
	 * Sets the value and the "other" field
	 * 
	 * @param  string|boolean $value OPTIONAL
	 * @return string|null
	 */
	protected function _value($value = null)
	{
		parent::_value($value);
		
		// Assign and return "other" field value using $_POST
		if ($this->property('other') === true
			&& $this->_value
			&& isset($_POST[$this->_other->name]))
		{
			$this->_other->value = $_POST[$this->_other->name];
		}
		
		return $this->_value;
	}
	
	/**
	 * Returns the label text if the checkbox is checked
	 * 
	 * @return string|null
	 */
	protected function _formattedValue()
	{
		// Other field, "Other (Foobar)"
		if ($this->property('other') === true && $this->value)
		{
			return 'Other' . (($this->_other->formattedValue != null) ? ' (' . $this->_other->formattedValue . ')' : null);
		}
		// Normal field
		elseif ($this->value)
		{
			return $this->label(null, false);
		}
		
		return null;
	}
}