<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

/**
 * Ranking text <input> list field option
 * 
 * @package    Pancake
 * @subpackage Fields
 * @see        \Pancake\Field\ListRanking
 */
class ListRankingOption extends InputText
{
	// Disable user creation of field
	public static $methodName = null;
	
	// Make each option a list item
	protected $_properties = array(
		'container' => 'li',
		'label_first' => false
	);
	
	// Require the parent name property
	protected $_validProperties = array(
		'parent_name' => null
	);
	protected $_requiredParameters = array(
		'parent_name'
	);
	
	/**
	 * Gives the field a unique name
	 * 
	 * Unlike the other list options, ranking options are not members of
	 * an "array" of fields.  Each specific field needs its own value, so
	 * they are named uniquely based on the parent name and the specific
	 * option's label.
	 */
	protected function _init()
	{
		$this->_name = $this->property('parent_name') . '_' . $this->_name;
		
		// Re-assign the ID and name attributes
		$this->_attributes['id'] = (string) $this->id;
		$this->_attributes['name'] = (string) $this->name;
		
		parent::_init();
	}
}