<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

use Pancake\Helper;

/**
 * <select> drop-down box field
 * 
 * Examples:
 * <code>
 * $form->select('numbers', array('one', 'two', 'three));
 * $form->select('numbers', array('one', 'two', 'three), array('include_blank' => false));
 * </code>
 * 
 * Field-specific properties:
 * - <b>include_blank:</b> OPTIONAL Whether or not to include a blank <option> (default: True)
 * - <b>options:</b>       REQUIRED List options
 * 
 * @package    Pancake
 * @subpackage Fields
 * @uses       \Pancake\Field\SelectOption
 */
class Select extends FieldList
{
	public static $methodName = 'select';
	protected $_paragraphClasses = array(
		'field',
		'select'
	);
	
	// <select> list settings
	protected $_optionClass = '\Pancake\Field\SelectOption';
	protected $_allowMultiples = false;
	
	// Whether or not to include a blank entry first
	protected $_validProperties = array(
		'include_blank' => true,
		'options' => array()
	);
	
	// XHTML attributes
	protected $_validAttributes = array(
		'disabled' => null,
		'multiple' => null,
		'size' => null
	);
	
	/**
	 * Handles the "multiple" attribute
	 */
	protected function _init()
	{
		if ($this->attribute('multiple') == 'multiple')
		{
			$this->_allowMultiples = true;
			$this->attribute('name', $this->name . '[]');
			
			// Disable the blank <option>, since it does not make much sense
			$this->property('include_blank', false);
		}
		
		parent::_init();
	}
	
	/**
	 * @return string
	 */
	public function output()
	{
		return '<select' . Helper\Attributes::process($this->_attributes) . '>' . (($this->property('include_blank')) ? '<option></option>' : null) . parent::output() . '</select>';
	}
}