<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

use Pancake\Helper;

/**
 * Select <option> list field option
 * 
 * @package    Pancake
 * @subpackage Fields
 * @see        \Pancake\Field\Select
 */
class SelectOption extends Field
{
	protected $_validAttributes = array(
		'disabled' => null,
		'selected' => null,
		'value' => null
	);
	protected $_autoNameAndId = false; // (no "id" or "name")
	
	// Require the parent name property (as a list option)
	protected $_validProperties = array(
		'parent_name' => null
	);
	protected $_requiredParameters = array(
		'parent_name'
	);
	
	// Hide the paragraph and label
	protected $_properties = array(
		'paragraph' => false,
		'show_label' => false
	);
	
	/**
	 * Assigns automatically the value attribute
	 */
	protected function _init()
	{
		$this->attribute('value', $this->name);
	}
	
	/**
	 * @return string
	 */
	public function output()
	{
		return '<option' . Helper\Attributes::process($this->_attributes) . '>' . $this->label(null, false) . '</option>';
	}
	
	/**
	 * Processes the value
	 * 
	 * Ensures the stored value is a boolean and the "selected"
	 * attribute is properly set, always returning a boolean
	 * 
	 * @param  string|boolean $value OPTIONAL
	 * @return boolean
	 */
	protected function _value($value = null)
	{
		if ($value === false || (is_string($value) && $value != $this->attribute('value')))
		{
			$this->_value = false;
			$this->attribute('selected', '');
		}
		elseif ($value === true || $value == $this->attribute('value'))
		{
			$this->_value = true;
			$this->attribute('selected', 'selected');
		}
		
		return $this->_value;
	}
	
	/**
	 * Returns the label text if the option is selected
	 * 
	 * @return string|null
	 */
	protected function _formattedValue()
	{
		return ($this->value) ? $this->label(null, false) : null;
	}
}