<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

use Pancake\Validator\IsStateOrProvince;

/**
 * US states and Canadian provinces <select> drop-down field
 * 
 * Examples:
 * <code>
 * $form->states('mailing_state');
 * $form->states('mailing_state', array('required' => false));
 * </code>
 * 
 * Field-specific properties:
 * - <b>include_blank:</b> OPTIONAL Whether or not to include a blank <option> (default: True)
 * 
 * @package    Pancake
 * @subpackage Fields
 */
class States extends Select
{
	public static $methodName = 'states';
	protected $_paragraphClasses = array(
		'field',
		'select',
		'states'
	);
	
	// Do not require options, since they are set by default
	protected $_requiredParameters = array();
	
	/**
	 * Provides states and provinces as the list options
	 */
	protected function _init()
	{
		$this->property('options', isStateOrProvince::$statesAndProvinces);
		parent::_init();
	}
}