<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Field;

use Pancake\Helper;

/**
 * <textarea> field
 * 
 * Examples:
 * <code>
 * $form->textarea('about_you', 10, 50);
 * $form->textarea('about_you', 10, 50, array('required' => false));
 * </code>
 * 
 * Following the XHTML DTD, both the "cols" and "rows" attribute are
 * required.
 * 
 * @package    Pancake
 * @subpackage Fields
 */
class Textarea extends Field
{
	public static $methodName = 'textarea';
	protected $_paragraphClasses = array(
		'field',
		'textarea'
	);
	protected $_validAttributes = array(
		'cols' => null,
		'disabled' => null,
		'name' => null,
		'readonly' => null,
		'rows' => null
	);
	
	// Required by XHTML DTD
	protected $_requiredParameters = array(
		'cols',
		'rows'
	);
	
	/**
	 * Adds default link-count validation
	 */
	protected function _init()
	{
		parent::_init();
		$this->_addValidation('HasLinkCount');
	}
	
	/**
	 * @return string
	 */
	public function output()
	{
		return '<textarea' . Helper\Attributes::process($this->_attributes) . '>' . $this->value . '</textarea>';
	}
}