<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Helper;

use Pancake\Exception;

/**
 * Forms a string of attributes
 * 
 * @package Pancake
 */
class Attributes implements Helper
{
	/**
	 * Forms a string of attributes
	 * 
	 * @param  array $attributes      Attributes (given the most weight)
	 * @param  array $defaults        Default values for each attributes
	 * @param  array $validAttributes All valid attributes
	 * @return string                 Formatted attributes
	 * 
	 * @throws Pancake\Exception\Exception  When the attributes are not all valid
	 * @throws Pancake\Exception\ValueError When an attribute does not have a proper key-value pair
	 */
	public static function process($attributes, $defaults = array(), $validAttributes = array())
	{
		// Ensure the attributes are valid by comparing the attribute keys to the valid attributes
		if (!empty($validAttributes)
			&& count(array_intersect($validAttributes, array_keys($attributes))) != count($attributes))
		{
			throw new Exception\Exception('Not all of the attributes are valid: ' . implode(', ', array_keys($attributes)));
		}
		
		// Merge with the defaults and then alphabetise
		$attributes = array_merge($defaults, $attributes);
		ksort($attributes);
		
		$return = array();
		foreach ($attributes as $attribute => $value)
		{
			// Make sure both the key and the value are set
			if (empty($attribute))
			{
				throw new Exception\ValueError('Both an attribute and a value are required for each attribute entry.');
			}
			// Only include the attributes with values
			elseif (!empty($value))
			{
				$return[] = $attribute . '="' . SUA::HTMLSafe($value) . '"';
			}
		}
		
		return (!empty($return)) ? ' ' . implode(' ', $return) : null;
	}
}