<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Hook;

/**
 * Handles file-upload logic
 * 
 * Examples:
 * <code>
 * $form->addHook('after', 'FileUpload');
 * </code>
 * 
 * This hook moves any files in the temporary upload directory to the
 * root upload directory.  Since hooks run after validation, the files
 * are already approved and valid.
 * 
 * @package    Pancake
 * @subpackage Hooks
 */
class FileUpload extends Hook
{
	/**
	 * Moves files out of the temporary directory
	 * 
	 * @param  array $fields
	 * @return boolean       Whether or not the hook ran successfully
	 */
	public function run($fields)
	{
		// Search for any file-upload fields
		foreach ($fields as $field)
		{
			if (get_class($field) == 'Pancake\Field\InputFile')
			{
				try
				{
					$field->moveOutOfTemp();
				}
				catch (Exception $e)
				{
					throw $e;
					return false;
				}
			}
		}
		
		return true;
	}
}