<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake;

/**
 * @see \Pancake\PancakeAbstract
 */
include_once 'Pancake/PancakeAbstract.php';

/**
 * SUA Pancake class
 * 
 * This class provides a place for all SUA-specific extensions to the Pancake
 * class itself.
 * 
 * @package Pancake
 */
class Pancake extends \Pancake\PancakeAbstract
{
	/**
	 * Returns the CSS and JavaScript files for Pancake forms
	 * 
	 * @param  boolean $includeCSS    Whether or not to include the CSS files
	 * @param  boolean $includeJS     Whether or not to include the JavaScript files
	 * @param  boolean $includeJQuery Whether or not to include jQuery automatically
	 * @return string
	 */
	public function resources($includeCSS = true, $includeJS = true, $includeJQuery = true)
	{
		$return = null;
		
		if ($includeCSS)
		{
			$return .= '<link href="' . Settings\Other::JS_PATH . 'jquery.datepick.media/redmond.datepick.css" rel="stylesheet" type="text/css" />
			<link rel="stylesheet" href="' . Settings\Other::CSS_PATH . 'pancake.css" media="screen,projection" />';
			
			// Internet Explorer fixes
			$return .= '<!--[if IE]>
				<link href="' . Settings\Other::CSS_PATH . 'pancake-ie.css" rel="stylesheet" type="text/css" />
			<![endif]-->';
		}
		
		if ($includeJQuery)
		{
			$return .= '<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.6.2/jquery.min.js"></script>';
		}
		
		if ($includeJS)
		{
			$return .= '<script type="text/javascript" src="' . Settings\Other::JS_PATH . 'jquery.datepick.js"></script>
			<script type="text/javascript" src="' . Settings\Other::JS_PATH . 'pancake.js"></script>';
		}
		
		return $return;
	}
	
	/**
	 * Notifies the webmaster of a runtime (hook) error
	 * 
	 * @param  string $subject
	 * @param  string $message
	 * @return boolean
	 */
	protected function _notifyWebmaster($subject, $message)
	{
		return mail(Settings\Other::WEBMASTER_EMAIL, $subject, $message);
	}
}