/**
 * Pancake Forms
 * 
 * @fileoverview
 * @author  Ethan Poole
 * @package pancake
 */

$(document).ready(function ()
{
	// Date calendars
	$('p.calendar input').datepick({
		buttonImage: '/css/pancake2/images/icon-calendar.png', // Thanks famfamfam silk icons!
		buttonImageOnly: true,
		showOn: 'both'
	});
	
	// Automatically select "other" checkbox/radio when a value is entered
	// in the corresponding text <input>
	function check_other()
	{
		$(this).siblings('input:radio').attr('checked', true);
		$(this).siblings('input:checkbox').attr('checked', true);
	}
	$('div.list input[type="text"]').click(check_other);
	$('div.list input[type="text"]').change(check_other); // For tabbing through the form fields
	
	// Automatically change the focus to the text <input> when the corresponding
	// checkbox/radio is checked
	$('div.list input[id$="other"]').change(function ()
	{
		$(this).siblings('input[type="text"]').focus();
	});
});

/**
 * Helper for a checkbox that hides/shows a set of conditional fields
 * 
 * @constructor
 * @param {String} checkbox     Checkbox that triggers the conditional fields to display
 * @param {String} conditionals <div> that contains the conditional fields
 */
function ConditionalCheckboxFields(checkbox, conditionals)
{
	var self = this;
	
	self._checkbox = $(checkbox);
	self._conditionals = $(conditionals);
	
	// Determine whether or not to hide the conditional fields
	if (!self._checkbox.is(':checked'))
	{
		self._conditionals.hide();
	}
	
	// Toggle the visiblity of the conditional fields based on the checkbox
	self._checkbox.change(function ()
	{
		if (self._checkbox.is(':checked'))
		{
			self._conditionals.slideDown();
		}
		else
		{
			self._conditionals.slideUp();
		}
	});
}

/**
 * Helper for a radio-button list in which specific options hide/show a set of conditional fields
 * 
 * @constructor
 * @param {String} radioListName Name of the list of radio buttons
 * @param {String} conditionals  <div> that contains the conditional fields
 * @param {Array}  options       Options that trigger the conditional fields to display
 */
function ConditionalRadioButtonFields(radioListName, conditionals, options)
{
	var self = this;
	
	self._radioListName = radioListName;
	self._conditionals = $(conditionals);
	self._options = options;
	
	// Determine whether a valid conditional option has been selected
	var show = false;
	var initialValue = $('input[name="' + self._radioListName + '"]:checked').val();
	var x = self._options.length;
	while (x--)
	{
		if (self._options[x] == initialValue)
		{
			show = true;
			break;
		}
	}
	
	// Hide the conditional fields
	if (!show)
	{
		self._conditionals.hide();
	}
	
	// Toggle the visiblity of the conditional fields based on the radio-list value
	$('input[name="' + self._radioListName + '"]').change(function ()
	{
		var slideDown = false;
		var currentValue = $(this).val();
		var x = self._options.length;
		while (x--)
		{
			if (self._options[x] == currentValue)
			{
				slideDown = true;
				break;
			}
		}
		
		(slideDown) ? self._conditionals.slideDown() : self._conditionals.slideUp();
	});
}

/**
 * Helper for a series of fieldsets where the non-first fieldsets
 * are optional and added by an "add" link.
 * 
 * @constructor
 * @param {String} container Container element which contains the fieldsets
 * @param {String} linkText  Link text for the "add link"
 * @param {Array}  fieldsets Fieldsets in the series
 */
function FieldsetSeries(container, linkText, fieldsets)
{
	var self = this;
	
	self._container = $(container);
	self._linkText = linkText;
	self._fieldsets = fieldsets;
	self._level = 0;
	
	// Determine which level of fieldsets to show
	var x = self._fieldsets.length;
	while (x--)
	{
		var y = x + 2;
		var hide = true;
		
		// Loop through the fields in the fieldset and determine if at least one of them is filled
		self._fieldsets[x].find('input').each(function ()
		{
			if ($(this).val())
			{
				hide = false;
				return false;
			}
		});
		
		// Either hide the fieldset and move on or stop here
		if (hide)
		{
			self._fieldsets[x].hide();
		}
		else
		{
			self._level = x + 1;
			break;
		}
	}
	
	// Link to add another fieldset
	if (self._level < self._fieldsets.length)
	{
		self._link = $('<p class="add"><a href="">' + self._linkText + '</a></p>').appendTo(self._container);
		self._link.find('a').click(function ()
		{
			self._level++;
			self._fieldsets[self._level - 1].slideDown();
			
			if (self._level == self._fieldsets.length)
			{
				$(this).parent().fadeOut();
			}
			
			return false;
		});
	}
}