<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

use Pancake\Settings;

/**
 * Link-count validator
 * 
 * Examples:
 * <code>
 * $hasLinkCount->validate('http://www.google.com http://www.yahoo.com'); // Default allowed link amount; True
 * $hasLinkCount->validate('http://www.google.com http://www.yahoo.com', 0); // Custom allowed link amount; False
 * </code>
 * 
 * @package    Pancake
 * @subpackage Validators
 */
class HasLinkCount extends Validator
{
	/**
	 * Assigns the central spam error message to the validator
	 */
	protected function _init()
	{
		$this->_error = Settings\Security::SPAM_MESSAGE;
	}
	
	/**
	 * @param  mixed   $value
	 * @param  integer $allowedLinks Allowed number of links
	 * @return boolean
	 */
	protected function _isTrue($value, $allowedLinks = 10)
	{
		return preg_match_all('#((http\:\/\/)?[a-zA-Z0-9_\-]+(?:\.[a-zA-Z0-9_\-]+)*\.[a-zA-Z]{2,4}(?:\/[a-zA-Z0-9_]+)*(?:\/[a-zA-Z0-9_]+\.[a-zA-Z]{2,4}(?:\?[a-zA-Z0-9_]+\=[a-zA-Z0-9_]+)?)?(?:\&[a-zA-Z0-9_]+\=[a-zA-Z0-9_]+)*)\b#i', $value, $matches) < $allowedLinks;
	}
}