<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

/**
 * Between validator
 * 
 * If passed a string, it uses the string length.
 * 
 * Examples:
 * <code>
 * $between->validate('string', 1, 20); // String length; True
 * $between->validate(2, 5, 10); // False
 * </code>
 * 
 * @package    Pancake
 * @subpackage Validators
 */
class IsBetween extends Validator
{
	/**
	 * Dynamic error message template
	 */
	const ERROR_MESSAGE = 'Please enter a value between %s and %s.';
	
	/**
	 * @param  mixed   $value
	 * @param  integer $min   Minimum value
	 * @param  integer $max   Maximum value
	 * @return boolean
	 */
	protected function _isTrue($value, $min, $max)
	{
		// Set the dynamic error message
		$this->_error = sprintf(isBetween::ERROR_MESSAGE, $min, $max);
		
		// For string length
		if (!is_numeric($value))
		{
			$value = strlen($value);
		}
		
		return $value >= $min && $value <= $max;
	}
}