<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

/**
 * Date validator
 * 
 * Examples:
 * <code>
 * $date->validate('2010-08-18'); // True
 * $date->validate('2010/08/18'); // True
 * $date->validate('08182010'); // True
 * $date->validate('18 August 2010'); // False
 * </code>
 * 
 * @package    Pancake
 * @subpackage Validators
 */
class IsDate extends Validator
{
	/**
	 * Preferred date format for anything being validated
	 */
	const DATE_FORMAT = 'Y-m-d';
	
	protected $_error = 'Please enter a valid date.';
	
	/**
	 * @param  mixed $value
	 * @return boolean
	 */
	protected function _isTrue($value)
	{
		// Make sure the format is valid
		if (preg_match('#^([0-9]){1,2}[- /]?([0-9]){1,2}[- /]?([0-9]{1,4})$#', $value) // Day or month first
			|| preg_match('#^([0-9]){1,4}[- /]?([0-9]){1,2}[- /]?([0-9]{1,2})$#', $value)) // Year first
		{
			$timestamp = getdate(strtotime($value));
			
			// Make sure the date itself is valid
			return checkdate($timestamp['mon'], $timestamp['mday'], $timestamp['year']);
		}
		else
		{
			return false;
		}
	}
}