<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

/**
 * Date month validator
 * 
 * Examples:
 * <code>
 * $month->validate(6); // Numeric value; True
 * $month->validate('February'); // Text value; True
 * $month->validate(13); // False
 * </code>
 * 
 * @package    Pancake
 * @subpackage Validators
 */
class IsDateMonth extends Validator
{
	protected $_error = 'Please enter a valid month (e.g. 12 or December).';
	
	/**
	 * @param  mixed $value
	 * @return boolean
	 */
	protected function _isTrue($value)
	{
		$isBetween = new IsBetween;
		
		$allMonths = array(
			'1' => 'January',
			'2' => 'February',
			'3' => 'March',
			'4' => 'April',
			'5' => 'May',
			'6' => 'June',
			'7' => 'July',
			'8' => 'August',
			'9' => 'September',
			'10' => 'October',
			'11' => 'November',
			'12' => 'December'
		);
		
		// Numeric value
		if ($isBetween->validate((int) $value, 1, 12) === true)
		{
			return true;
		}
		// String that might be a month
		elseif (in_array((string) $value, $allMonths))
		{
			return true;
		}
		else
		{
			return false;
		}
	}
}