<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

/**
 * Currency and money validator
 * 
 * Examples:
 * <code>
 * $money->validate('$1.23'); // US dollars; True
 * $money->validate('£1.23'); // British pounds sterling; True
 * $money->validate('€1.23'); // Euros; True
 * $money->validate('2..66'); // False
 * </code>
 * 
 * @package    Pancake
 * @subpackage Validators
 */
class IsMoney extends Validator
{
	protected $_error = 'Please enter a currency value in the form $1.23.';
	
	/**
	 * @param  mixed $value
	 * @return boolean
	 */
	protected function _isTrue($value)
	{
		return !empty($value) && preg_match('#^(\$|\£|\€)?([1-9]{1}[0-9]{0,2}([\s\,][0-9]{3})*(\.[0-9]{0,2})?|[1-9]{1}[0-9]{0,}(\.[0-9]{0,2})?|0(\.[0-9]{0,2})?|(\.[0-9]{1,2})?)$#', $value);
	}
}