<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

/**
 * Selection choice validator
 * 
 * Examples:
 * <code>
 * $oneOf->validate('en', array('en', 'två', 'tre')); // True
 * $oneOf->validate(array('en', 'två'), array('en', 'två', 'tre')); // True
 * $oneOf->validate('fyra', array('en', 'två', 'tre')); // False
 * $oneOf->validate(array('en', 'fyra'), array('en', 'två', 'tre')); // False
 * </code>
 * 
 * If you want to use the {@link isOneOf::MULTIPLE_OPTIONS_ERROR} error message,
 * you must do so manually as an option to {@link PancakeField::_addValidation()}.
 * The validator has no means of determining whether multiple options are allowed.
 * 
 * @package    Pancake
 * @subpackage Validators
 */
class IsOneOf extends Validator
{
	/**
	 * Error message when the user can select multiple options
	 */
	const MULTIPLE_OPTIONS_ERROR = 'Please select one or more options.';
	
	protected $_error = 'Please select an option.';
	
	/**
	 * @param  mixed $value        Needle
	 * @param  mixed $possible,... Haystack
	 * @return boolean
	 */
	protected function _isTrue()
	{
		$arguments = func_get_args();
		$value = array_shift($arguments);
		$possible = $arguments;
		
		// In case it is more convenient to pass as an array
		if (is_array($possible[0]))
		{
			$possible = $possible[0];
		}
		
		// Often checkboxes and radio use foo[], so loop through the
		// values and check each value
		if (is_array($value))
		{
			foreach ($value as $subValue)
			{
				if (!in_array($subValue, $possible))
				{
					return false;
				}
			}
			
			return true;
		}
		elseif (in_array($value, $possible))
		{
			return true;
		}
		else
		{
			return false;
		}
	}
}