<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

/**
 * US and Canadian postal code validator
 * 
 * Examples:
 * <code>
 * $postalCode->validate('55455'); // US ZIP codes; True
 * $postalCode->validate('55455-3000'); // Extended US ZIP codes; True
 * $postalCode->validate('H3Z 2Y7'); // Canadian postal codes; True
 * $postalCode->validate('EC1Y 8SY'); // False
 * </code>
 *
 * @package    Pancake
 * @subpackage Validators
 */
class IsPostalCode extends Validator
{
	protected $_error = 'Please enter a valid ZIP code.';
	
	/**
	 * @param  mixed $value
	 * @return boolean
	 */
	protected function _isTrue($value)
	{
		return preg_match('#(^\d{5}(-\d{4})?$)|(^[ABCEGHJKLMNPRSTVXY]{1}\d{1}[A-Z]{1} *\d{1}[A-Z]{1}\d{1}$)#', $value);
	}
}