<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

/**
 * Ranked values validator
 * 
 * Examples:
 * <code>
 * $ranked->validate(array(1, 2), 2); // True
 * $ranked->validate(array(1), 2); // Minimum required value; False
 * $ranked->validate(array(1, 3), 2); // Must be consecutively ranked; False
 * $ranked->validate(array(1, 1), 2); // No duplicates; False
 * </code>
 * 
 * @package    Pancake
 * @subpackage Validators
 */
class IsRanked extends Validator
{
	/**
	 * Dynamic error message template
	 */
	const ERROR_MESSAGE = 'Please rank each option uniquely from %s to %s.';
	
	/**
	 * @param  mixed   $values
	 * @param  integer $min    Minimum number of required rank values
	 * @return boolean
	 */
	protected function _isTrue($values, $min)
	{
		// Set the dynamic error message
		$this->_error = sprintf(isRanked::ERROR_MESSAGE, '1', $min);
		
		// Remove empty values from the values array
		foreach ($values as $key => $value)
		{
			if ($value == null)
			{
				unset($values[$key]);
			}
		}
		
		// Array to which to compare the values
		$compareTo = range(1, $min);
		
		sort($values);
		return $compareTo == $values;
	}
}