<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

/**
 * US state and Canadian province validator
 * 
 * Examples:
 * <code>
 * $state->validate('MN'); // US state; True
 * $state->validate('BC'); // Canadian province; True
 * $state->validate('Florida'); // Text value; True
 * $state->validate('Canada'); // False
 * </code>
 * 
 * @package    Pancake
 * @subpackage Validators
 */
class IsStateOrProvince extends Validator
{
	protected $_error = 'Please select a valid US state or Canadian province.';
	
	/**
	 * Valid US states and Canadian provinces
	 * 
	 * @var array
	 */
 	public static $statesAndProvinces = array(
		'AB' => 'alberta',
		'AL' => 'alabama',
		'AK' => 'alaska',
		'AS' => 'american samoa',
		'AZ' => 'arizona',
		'AR' => 'arkansas',
		'BC' => 'british columbia',
		'CA' => 'california',
		'CO' => 'colorado',
		'CT' => 'connecticut',
		'DC' => 'district of columbia',
		'DE' => 'delaware',
		'FM' => 'federated states of micronesia',
		'FL' => 'florida',
		'GA' => 'georgia',
		'GU' => 'guam',
		'HI' => 'hawaii',
		'ID' => 'idaho',
		'IL' => 'illinois',
		'IN' => 'indiana',
		'IA' => 'iowa',
		'KS' => 'kansas',
		'KY' => 'kentucky',
		'LA' => 'louisiana',
		'ME' => 'maine',
		'MB' => 'manitoba',
		'MH' => 'marshall islands',
		'MD' => 'maryland',
		'MA' => 'massachusetts',
		'MI' => 'michigan',
		'MN' => 'minnesota',
		'MS' => 'mississippi',
		'MO' => 'missouri',
		'MT' => 'montana',
		'NB' => 'new brunswick',
		'NE' => 'nebraska',
		'NL' => 'newfoundland and labrador',
		'NV' => 'nevada',
		'MP' => 'northern mariana islands',
		'NS' => 'nova scotia',
		'NT' => 'northwest territories',
		'NU' => 'nunavut',
		'NH' => 'new hampshire',
		'NJ' => 'new jersey',
		'NM' => 'new mexico',
		'NY' => 'new york',
		'NC' => 'north carolina',
		'ND' => 'north dakota',
		'OH' => 'ohio',
		'OK' => 'oklahoma',
		'ON' => 'ontario',
		'OR' => 'oregon',
		'PW' => 'palau',
		'PA' => 'pennsylvania',
		'PE' => 'prince edward island',
		'PR' => 'puerto rico',
		'RI' => 'rhode island',
		'QC' => 'quebec',
		'SC' => 'south carolina',
		'SD' => 'south dakota',
		'SK' => 'saskatchewan',
		'TN' => 'tennessee',
		'TX' => 'texas',
		'UT' => 'utah',
		'VT' => 'vermont',
		'VA' => 'virginia',
		'VI' => 'virgin islands',
		'WA' => 'washington',
		'WV' => 'west virginia',
		'WI' => 'wisconsin',
		'WY' => 'wyoming',
		'YT' => 'yukon'
	);
	
	/**
	 * @param  mixed $value
	 * @return boolean
	 */
	protected function _isTrue($value)
	{
		// Allow both full names and abbreviations
		return in_array(strtolower($value), isStateOrProvince::$statesAndProvinces) || isset(isStateOrProvince::$statesAndProvinces[strtoupper($value)]);
	}
}