<?php
/**
 * Pancake Forms
 * 
 * @author     Ethan Poole
 * @package    Pancake
 * @subpackage Validators
 */

namespace Pancake\Validator;

use Pancake\Settings;

/**
 * Date range validator
 * 
 * Minimum and maximum date values are parsed with {@link strtotime()}.
 * 
 * Examples:
 * <code>
 * $dateRange->validate(time(), 'today', '+2 years'); // True
 * $dateRange->validate(strtotime('-1 day'), 'today', '+2 years'); // False
 * </code>
 * 
 * @package    Pancake
 * @subpackage Validators
 */
class IsWithinDateRange extends Validator
{
	/**
	 * Dynamic error message template
	 */
	const ERROR_MESSAGE = 'Please enter a valid date between %s and %s.';
	
	/**
	 * @param  mixed  $value
	 * @param  string $minDate Minimum date
	 * @param  string $maxDate Maximum date
	 * @return boolean
	 */
	protected function _isTrue($value, $minDate, $maxDate)
	{
		$minDate = (!is_numeric($minDate)) ? strtotime($minDate) : $minDate;
		$maxDate = (!is_numeric($maxDate)) ? strtotime($maxDate) : $maxDate;
		
		// Set the dynamic error message
		$this->_error = sprintf(IsWithinDateRange::ERROR_MESSAGE, date(Settings\Dates::DATETIME_FORMAT, $minDate), date(Settings\Dates::DATETIME_FORMAT, $maxDate));
		
		// Make sure valid if not a Unix timestamp
		if (!is_numeric($value))
		{
			$isDate = new IsDate;
			
			if (!$isDate->validate($value))
			{
				return false;
			}
			else
			{
				$value = strtotime($value);
			}
		}
		
		return ($minDate != null || $maxDate != null)
			&& ($minDate == null || $value > $minDate)
			&& ($maxDate == null || $value < $maxDate);
	}
}