<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Validator;

/**
 * Base validator class
 * 
 * Validators are used to ensure users enter the correct type of data.  Each
 * validation class returns either true or false.  This class handles
 * returning an error message.
 * 
 * @package    Pancake
 * @subpackage Validators
 */
abstract class Validator
{
	/**
	 * Error message
	 * 
	 * @var string
	 */
	protected $_error = 'Error';
	
	/**
	 * Calls the validator-specific constructor
	 */
	public function __construct()
	{
		$this->_init();
	}
	
	/**
	 * Validator-specific constructor
	 * 
	 * Called after {@link \Pancake\Validator\Validator::__construct()}.
	 */
	protected function _init()
	{
		
	}
	
	/**
	 * Runs the validation function
	 * 
	 * @return boolean|string True if valid and the error message otherwise
	 */
	public function validate()
	{
		$parameters = func_get_args();
		$valid = call_user_func_array(array($this, '_isTrue'), $parameters);
		
		return ($valid == true) ? true : $this->_error;
	}
	
	/**
	 * @param  string $member
	 * @return mixed
	 */
	public function __get($member)
	{
		if ($member == 'error_message')
		{
			return $this->_error;
		}
	}
}