<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\DateDropDowns;

/**
 * {@link \Pancake\Field\DateDropDowns} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class DateDropDownsTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\DateDropDowns'));
		$this->assertEqual('Pancake\Field\Field', get_parent_class('\Pancake\Field\DateDropDowns'));
		$this->assertEqual(DateDropDowns::$methodName, 'dateDropDowns');
	}
	
	function testFormattedValue()
	{
		$field = new DateDropDowns('birthday', array('value' => time()));
		$this->assertEqual($field->formattedValue, date('l, j F Y', time()));
		
		$field = new DateDropDowns('birthday', array('value' => time(), 'date_format' => 'F'));
		$this->assertEqual($field->formattedValue, date('F', time()));
	}
	
	function testOptional()
	{
		$field = new DateDropDowns('birthday', array('required' => false));
		$this->assertTrue($field->isValid());
	}
	
	function testOutput()
	{
		$field = new DateDropDowns('graduation');
		$this->assertEqual($field->__toString(), '<div class="date date-drop-downs field"><h3>Graduation</h3><p class="field select"><label for="f_graduation_day">Graduation Day</label><select class="day" id="f_graduation_day" name="graduation_day"><option></option><option value="1">1</option><option value="2">2</option><option value="3">3</option><option value="4">4</option><option value="5">5</option><option value="6">6</option><option value="7">7</option><option value="8">8</option><option value="9">9</option><option value="10">10</option><option value="11">11</option><option value="12">12</option><option value="13">13</option><option value="14">14</option><option value="15">15</option><option value="16">16</option><option value="17">17</option><option value="18">18</option><option value="19">19</option><option value="20">20</option><option value="21">21</option><option value="22">22</option><option value="23">23</option><option value="24">24</option><option value="25">25</option><option value="26">26</option><option value="27">27</option><option value="28">28</option><option value="29">29</option><option value="30">30</option><option value="31">31</option></select></p><p class="field select"><label for="f_graduation_month">Graduation Month</label><select class="month" id="f_graduation_month" name="graduation_month"><option></option><option value="january">January</option><option value="february">February</option><option value="march">March</option><option value="april">April</option><option value="may">May</option><option value="june">June</option><option value="july">July</option><option value="august">August</option><option value="september">September</option><option value="october">October</option><option value="november">November</option><option value="december">December</option></select></p><p class="field select"><label for="f_graduation_year">Graduation Year</label><select class="year" id="f_graduation_year" name="graduation_year"><option></option><option value="2006">2006</option><option value="2007">2007</option><option value="2008">2008</option><option value="2009">2009</option><option value="2010">2010</option><option value="2011">2011</option><option value="2012">2012</option><option value="2013">2013</option><option value="2014">2014</option><option value="2015">2015</option><option value="2016">2016</option></select></p></div>');
	}
	
	function testSetValue()
	{
		$field = new DateDropDowns('birthday', array('value' => time()));
		$this->assertEqual($field->childFields['birthday_day']->value, array(date('j', time())));
		$this->assertEqual($field->value, date('Y-m-d', time()));
	}
		
	function testValidation()
	{
		$field = new DateDropDowns('birthday', array('value' => time()));
		$this->assertTrue($field->isValid());
		
		$field->value = 'foobar';
		$this->assertFalse($field->isValid());
	}
	
	function testYearRange()
	{
		$field = new DateDropDowns('graduation', array('year_start' => 1980, 'year_end' => '1985'));
		$this->assertEqual($field->__toString(), '<div class="date date-drop-downs field"><h3>Graduation</h3><p class="field select"><label for="f_graduation_day">Graduation Day</label><select class="day" id="f_graduation_day" name="graduation_day"><option></option><option value="1">1</option><option value="2">2</option><option value="3">3</option><option value="4">4</option><option value="5">5</option><option value="6">6</option><option value="7">7</option><option value="8">8</option><option value="9">9</option><option value="10">10</option><option value="11">11</option><option value="12">12</option><option value="13">13</option><option value="14">14</option><option value="15">15</option><option value="16">16</option><option value="17">17</option><option value="18">18</option><option value="19">19</option><option value="20">20</option><option value="21">21</option><option value="22">22</option><option value="23">23</option><option value="24">24</option><option value="25">25</option><option value="26">26</option><option value="27">27</option><option value="28">28</option><option value="29">29</option><option value="30">30</option><option value="31">31</option></select></p><p class="field select"><label for="f_graduation_month">Graduation Month</label><select class="month" id="f_graduation_month" name="graduation_month"><option></option><option value="january">January</option><option value="february">February</option><option value="march">March</option><option value="april">April</option><option value="may">May</option><option value="june">June</option><option value="july">July</option><option value="august">August</option><option value="september">September</option><option value="october">October</option><option value="november">November</option><option value="december">December</option></select></p><p class="field select"><label for="f_graduation_year">Graduation Year</label><select class="year" id="f_graduation_year" name="graduation_year"><option></option><option value="1980">1980</option><option value="1981">1981</option><option value="1982">1982</option><option value="1983">1983</option><option value="1984">1984</option><option value="1985">1985</option></select></p></div>');
	}
}