<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\DateEstimation;

/**
 * {@link \Pancake\Field\DateEstimation} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class DateEstimationTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\DateEstimation'));
		$this->assertEqual('Pancake\Field\Field', get_parent_class('\Pancake\Field\DateEstimation'));
		$this->assertEqual(DateEstimation::$methodName, 'dateEstimation');
	}
	
	function testFormattedValue()
	{
		$field = new DateEstimation('graduation', array('value' => 'spring 2012'));
		$this->assertEqual($field->formattedValue, 'Spring 2012');
	}
	
	function testOutput()
	{
		$field = new DateEstimation('graduation');
		$this->assertEqual($field->__toString(), '<div class="date date-drop-downs field"><h3>Graduation</h3><p class="field select"><label for="f_graduation_semester">Graduation Semester</label><select class="semester" id="f_graduation_semester" name="graduation_semester"><option></option><option value="fall">Fall</option><option value="spring">Spring</option><option value="summer">Summer</option></select></p><p class="field select"><label for="f_graduation_year">Graduation Year</label><select class="year" id="f_graduation_year" name="graduation_year"><option></option><option value="2006">2006</option><option value="2007">2007</option><option value="2008">2008</option><option value="2009">2009</option><option value="2010">2010</option><option value="2011">2011</option><option value="2012">2012</option><option value="2013">2013</option><option value="2014">2014</option><option value="2015">2015</option><option value="2016">2016</option></select></p></div>');
	}
	
	function testSetValue()
	{
		$field = new DateEstimation('graduation', array('value' => 'Fall 2010'));
		$this->assertEqual($field->childFields['graduation_semester']->value, array('fall'));
		$this->assertEqual($field->value, 'fall 2010');
	}
	
	function testValidation()
	{
		$field = new DateEstimation('graduation');
		
		$field->value = 'Summer 2011';
		$this->assertTrue($field->isValid());
		
		$field->value = 'foobar';
		$this->assertFalse($field->isValid());
	}
	
	function testYearRange()
	{
		$field = new DateEstimation('graduation', array('year_start' => 1980, 'year_end' => '1985'));
		$this->assertEqual($field->__toString(), '<div class="date date-drop-downs field"><h3>Graduation</h3><p class="field select"><label for="f_graduation_semester">Graduation Semester</label><select class="semester" id="f_graduation_semester" name="graduation_semester"><option></option><option value="fall">Fall</option><option value="spring">Spring</option><option value="summer">Summer</option></select></p><p class="field select"><label for="f_graduation_year">Graduation Year</label><select class="year" id="f_graduation_year" name="graduation_year"><option></option><option value="1980">1980</option><option value="1981">1981</option><option value="1982">1982</option><option value="1983">1983</option><option value="1984">1984</option><option value="1985">1985</option></select></p></div>');
	}
}