<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\Date;

/**
 * {@link \Pancake\Field\Date} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class DateTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\Date'));
		$this->assertEqual('Pancake\Field\Field', get_parent_class('\Pancake\Field\Date'));
		$this->assertEqual(Date::$methodName, 'date');
	}
	
	function testDefaultOutput()
	{
		$field = new Date('birthday');
		$this->assertEqual($field->__toString(), '<div class="date field"><h3>Birthday</h3><p class="field text"><label for="f_birthday_day"><span class="hide">Birthday </span>Day</label><input class="day" id="f_birthday_day" maxlength="2" name="birthday_day" type="text" /></p><p class="field text"><label for="f_birthday_month"><span class="hide">Birthday </span>Month</label><input class="month" id="f_birthday_month" maxlength="2" name="birthday_month" type="text" /></p><p class="field text"><label for="f_birthday_year"><span class="hide">Birthday </span>Year</label><input class="year" id="f_birthday_year" maxlength="4" name="birthday_year" type="text" /></p></div>');
	}
	
	function testFormattedValue()
	{
		$field = new Date('birthday', array('value' => time()));
		$this->assertEqual($field->formattedValue, date('l, j F Y', time()));
		
		$field = new Date('birthday', array('value' => time(), 'date_format' => 'F'));
		$this->assertEqual($field->formattedValue, date('F', time()));
	}
	
	function testPseudoLabelTag()
	{
		$field = new Date('birthday', array('label_element' => 'h4'));
		$this->assertEqual($field->__toString(), '<div class="date field"><h4>Birthday</h4><p class="field text"><label for="f_birthday_day"><span class="hide">Birthday </span>Day</label><input class="day" id="f_birthday_day" maxlength="2" name="birthday_day" type="text" /></p><p class="field text"><label for="f_birthday_month"><span class="hide">Birthday </span>Month</label><input class="month" id="f_birthday_month" maxlength="2" name="birthday_month" type="text" /></p><p class="field text"><label for="f_birthday_year"><span class="hide">Birthday </span>Year</label><input class="year" id="f_birthday_year" maxlength="4" name="birthday_year" type="text" /></p></div>');
		
		$field = new Date('birthday', array('label_element' => 'h4', 'required' => false));
		$this->assertEqual($field->__toString(), '<div class="date field optional"><h4>Birthday <em class="optional">(optional)</em></h4><p class="field optional text"><label for="f_birthday_day"><span class="hide">Birthday </span>Day</label><input class="day" id="f_birthday_day" maxlength="2" name="birthday_day" type="text" /></p><p class="field optional text"><label for="f_birthday_month"><span class="hide">Birthday </span>Month</label><input class="month" id="f_birthday_month" maxlength="2" name="birthday_month" type="text" /></p><p class="field optional text"><label for="f_birthday_year"><span class="hide">Birthday </span>Year</label><input class="year" id="f_birthday_year" maxlength="4" name="birthday_year" type="text" /></p></div>');
	}
	
	function testOptional()
	{
		$field = new Date('birthday', array('required' => false));
		$this->assertTrue($field->isValid());
	}
	
	function testSetValue()
	{
		$field = new Date('birthday', array('value' => time()));
		$this->assertEqual($field->childFields['birthday_day']->value, date('j', time()));
		$this->assertEqual($field->value, date('Y-m-d', time()));
	}
	
	function testValidation()
	{
		$field = new Date('birthday', array('value' => time()));
		$this->assertTrue($field->isValid());
		
		$field->value = 'foobar';
		$this->assertFalse($field->isValid());
	}
}