<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\InputCheckbox;

/**
 * {@link \Pancake\Field\InputCheckbox} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class InputCheckboxText extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\InputCheckbox'));
		$this->assertEqual('Pancake\Field\Input', get_parent_class('\Pancake\Field\InputCheckbox'));
		$this->assertEqual(InputCheckbox::$methodName, 'checkbox');
	}
	
	function testDefaultOutput()
	{
		$field = new InputCheckbox('foobar');
		$this->assertEqual($field->output(), '<input id="f_foobar" name="foobar" type="checkbox" value="yes" />');
	}
	
	function testDefaultValue()
	{
		$field = new InputCheckbox('foobar');
		$this->assertFalse($field->value);
	}
	
	function testParagraphOutput()
	{
		$field = new InputCheckbox('foobar');
		$this->assertEqual($field->__toString(), '<p class="checkbox field optional"><input id="f_foobar" name="foobar" type="checkbox" value="yes" /><label for="f_foobar">Foobar</label></p>');
	}
	
	function testSetValue()
	{
		$field = new InputCheckbox('foobar');
		
		$field->value = true;
		$this->assertEqual($field->output(), '<input checked="checked" id="f_foobar" name="foobar" type="checkbox" value="yes" />');
		$this->assertTrue($field->value);
		
		$field->value = false;
		$this->assertEqual($field->output(), '<input id="f_foobar" name="foobar" type="checkbox" value="yes" />');
		$this->assertFalse($field->value);
		
		$field->value = 'yes';
		$this->assertEqual($field->output(), '<input checked="checked" id="f_foobar" name="foobar" type="checkbox" value="yes" />');
		$this->assertTrue($field->value);
		
		$field->value = 'no';
		$this->assertEqual($field->output(), '<input id="f_foobar" name="foobar" type="checkbox" value="yes" />');
		$this->assertFalse($field->value);
	}
	
	function testValidation()
	{
		$field = new InputCheckbox('foobar');
		$field->value = 'foobar'; // will essentially be ignored
		$this->assertTrue($field->isValid());
	}
}