<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\InputFile;

/**
 * {@link \Pancake\Field\InputFile} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class InputFileTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\InputFile'));
		$this->assertEqual('Pancake\Field\Input', get_parent_class('\Pancake\Field\InputFile'));
		$this->assertEqual(InputFile::$methodName, 'fileUpload');
	}
	
	function testCustomFieldOptions()
	{
		$field = new InputFile('file', array(
			'upload_to' => __DIR__ . '/../../upload',
			'valid_types' => array('application/pdf' => '.pdf', 'application/msword' => '.doc')
		));
		
		$this->assertEqual($field->property('upload_to'), __DIR__ . '/../../upload');
		$this->assertEqual($field->property('valid_types'), array('application/pdf' => '.pdf', 'application/msword' => '.doc'));
	}
	
	function testDefaultFieldOptions()
	{
		$field = new InputFile('file');
		
		$this->assertEqual($field->property('upload_to'), str_replace('/index.php', null, $_SERVER['SCRIPT_FILENAME']) . '/upload');
		$this->assertEqual($field->property('valid_types'), array());
	}
	
	function testInvalidDirectories()
	{
		try
		{
			$field = new InputFile('file', array(
				'upload_to' => '/var/www/users/pool0079/upload'
			));
			$this->fail('Exception expected.');
		}
		catch (Exception\FileError $e)
		{
			$this->pass();
		}
		
		try
		{
			$field = new InputFile('file', array(
				'upload_to' => '/var/www/users/pool0079/unit-tests/files'
			));
			$this->fail('Exception expected.');
		}
		catch (Exception\FileError $e)
		{
			$this->pass();
		}
	}
	
	function testOutput()
	{
		$field = new InputFile('file');
		$this->assertEqual($field->__toString(), '<p class="field file-upload"><label for="f_file">File</label><input id="f_file_file_name" name="file_file_name" type="hidden" /><input id="f_file" name="file" type="file" /></p>');
	}
}