<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\Input;

/**
 * {@link \Pancake\Field\Input} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class InputTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\Input'));
		$this->assertEqual('Pancake\Field\Field', get_parent_class('\Pancake\Field\Input'));
		$this->assertEqual(Input::$methodName, 'input');
	}
	
	function testAttributes()
	{
		$field = new Input('foobar', 'text', array('class' => 'baz'));
		$this->assertEqual($field->output(), '<input class="baz" id="f_foobar" name="foobar" type="text" />');
	}
	
	function testBasicOutput()
	{
		$field = new Input('foobar', 'text');
		$this->assertEqual($field->output(), '<input id="f_foobar" name="foobar" type="text" />');
	}
	
	function testInvalidInputType()
	{
		try
		{
			$field = new Input('foobar', 'foobar');
			$this->fail('Exception was expected.');
		}
		catch (Exception\ValueError $e)
		{
			$this->pass();
		}
	}	
	
	function testParagraphClass()
	{
		$field = new Input('foobar', 'text');
		$this->assertEqual($field->__toString(), '<p class="field"><label for="f_foobar">Foobar</label><input id="f_foobar" name="foobar" type="text" /></p>');
	}
	
	function testValue()
	{
		$field = new Input('foobar', 'text', array('class' => 'baz', 'value' => 'hejsan'));
		$this->assertEqual($field->output(), '<input class="baz" id="f_foobar" name="foobar" type="text" value="hejsan" />');
	}
}