<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\ListCheckboxes;

/**
 * {@link \Pancake\Field\ListCheckboxes} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class ListCheckboxesTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\ListCheckboxes'));
		$this->assertEqual('Pancake\Field\FieldList', get_parent_class('\Pancake\Field\ListCheckboxes'));
		$this->assertEqual(ListCheckboxes::$methodName, 'checkboxList');
	}
	
	function testCustomCheckboxes()
	{
		$field = new ListCheckboxes('foo', array(array('bar', array('after' => 'kiitos')), 'baz'));
		$this->assertEqual($field->output(), '<ul><li class="checkbox field optional"><input id="f_foo_bar" name="foo[]" type="checkbox" value="bar" /><label for="f_foo_bar">Bar</label>kiitos</li><li class="checkbox field optional"><input id="f_foo_baz" name="foo[]" type="checkbox" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
	}
	
	function testCustomCheckboxesWithTooManyParameters()
	{
		try
		{
			$field = new ListCheckboxes('foo', array(array('bar', 'test', array('after' => 'kiitos')), 'baz'));
			$this->fail('Exception was expected.');
		}
		catch (Exception\Exception $e)
		{
			$this->pass();
		}
	}
	
	function testDefaultOutput()
	{
		$field = new ListCheckboxes('foo', array('bar', 'baz'));
		$this->assertEqual($field->output(), '<ul><li class="checkbox field optional"><input id="f_foo_bar" name="foo[]" type="checkbox" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="checkbox field optional"><input id="f_foo_baz" name="foo[]" type="checkbox" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
	}
	
	function testInvalidFieldNames()
	{
		$field = new ListCheckboxes('foo', array('foo bar', 'baz'));
		$this->assertEqual($field->output(), '<ul><li class="checkbox field optional"><input id="f_foo_foo_bar" name="foo[]" type="checkbox" value="foo_bar" /><label for="f_foo_foo_bar">Foo Bar</label></li><li class="checkbox field optional"><input id="f_foo_baz" name="foo[]" type="checkbox" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
	}
	
	function testParargraphOutput()
	{
		$field = new ListCheckboxes('foo', array('bar', 'baz'));
		$this->assertEqual($field->__toString(), '<div class="checkbox-list field list"><h3>Foo</h3><ul><li class="checkbox field optional"><input id="f_foo_bar" name="foo[]" type="checkbox" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="checkbox field optional"><input id="f_foo_baz" name="foo[]" type="checkbox" value="baz" /><label for="f_foo_baz">Baz</label></li></ul></div>');
	}
	
	function testRequiredCheckboxes()
	{
		try
		{
			$field = new ListCheckboxes('foo');
			$this->fail('Exception was expected.');
		}
		catch (Exception\MissingArgument $e)
		{
			$this->pass();
		}
		
		try
		{
			$field = new ListCheckboxes('foo', array());
			$this->fail('Exception was expected.');
		}
		catch (Exception\MissingArgument $e)
		{
			$this->pass();
		}
	}
	
	function testSetValue()
	{
		$field = new ListCheckboxes('foo', array('bar', 'baz'));
		$field->value = 'bar';
		$this->assertEqual($field->output(), '<ul><li class="checkbox field optional"><input checked="checked" id="f_foo_bar" name="foo[]" type="checkbox" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="checkbox field optional"><input id="f_foo_baz" name="foo[]" type="checkbox" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
		
		$field->value = array('bar', 'baz');
		$this->assertEqual($field->output(), '<ul><li class="checkbox field optional"><input checked="checked" id="f_foo_bar" name="foo[]" type="checkbox" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="checkbox field optional"><input checked="checked" id="f_foo_baz" name="foo[]" type="checkbox" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
		
		$field->value = 'baz';
		$this->assertEqual($field->output(), '<ul><li class="checkbox field optional"><input id="f_foo_bar" name="foo[]" type="checkbox" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="checkbox field optional"><input checked="checked" id="f_foo_baz" name="foo[]" type="checkbox" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
	}
	
	function testValidation()
	{
		$field = new ListCheckboxes('foo', array('bar', 'baz'));
		$field->value = 'foobar';
		$this->assertFalse($field->isValid());
	}
}

/**
 * {@link \Pancake\Field\ListCheckboxes} unit tests for "other" field
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class ListCheckboxesOtherFieldTest extends Test
{
	function testAsCheckbox()
	{
		$field = new ListCheckboxes('foo', array('bar', 'other'));
		$this->assertEqual($field->output(), '<ul><li class="checkbox field optional"><input id="f_foo_bar" name="foo[]" type="checkbox" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="checkbox field optional"><input id="f_foo_other" name="foo[]" type="checkbox" value="other" /><label for="f_foo_other_text">Other:</label><input id="f_foo_other_text" name="foo_other_text" type="text" /></li></ul>');
	}
	
	function testBackwardsCompatibility()
	{
		$field = new ListCheckboxes('foo', array('bar', '{other}'));
		$this->assertEqual($field->output(), '<ul><li class="checkbox field optional"><input id="f_foo_bar" name="foo[]" type="checkbox" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="checkbox field optional"><input id="f_foo_other" name="foo[]" type="checkbox" value="other" /><label for="f_foo_other_text">Other:</label><input id="f_foo_other_text" name="foo_other_text" type="text" /></li></ul>');
	}
	
	function testFormattedValue()
	{
		$field = new ListCheckboxes('foo', array('bar', 'other'));
		$_POST['foo_other_text'] = 'Ja';
		$field->value = array('bar', 'other');
		
		$this->assertEqual($field->formattedValue, 'Bar, Other (Ja)');
		
		unset($_POST);
		
		$field = new ListCheckboxes('foo', array('bar', 'other'));
		$field->value = array('bar', 'other');
		
		$this->assertEqual($field->formattedValue, 'Bar, Other');
	}
	
	function testValidation()
	{
		$field = new ListCheckboxes('foo', array('bar', 'other'));
		$_POST['foo_other_text'] = 'ja';
		$field->value = array('bar', 'other');
		
		$this->assertTrue($field->isValid());
		
		unset($_POST);
	}	
}