<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\ListRadios;

/**
 * {@link \Pancake\Field\ListRadios} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class ListRadiosTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\ListRadios'));
		$this->assertEqual('Pancake\Field\ListCheckboxes', get_parent_class('\Pancake\Field\ListRadios'));
		$this->assertEqual(ListRadios::$methodName, 'radioList');
	}
	
	function testCustomCheckboxes()
	{
		$field = new ListRadios('foo', array(array('bar', array('after' => 'kiitos')), 'baz'));
		$this->assertEqual($field->output(), '<ul><li class="field optional radio"><input id="f_foo_bar" name="foo" type="radio" value="bar" /><label for="f_foo_bar">Bar</label>kiitos</li><li class="field optional radio"><input id="f_foo_baz" name="foo" type="radio" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
	}
	
	function testCustomCheckboxesWithTooManyParameters()
	{
		try
		{
			$field = new ListRadios('foo', array(array('bar', 'test', array('after' => 'kiitos')), 'baz'));
			$this->fail('Exception was expected.');
		}
		catch (Exception\Exception $e)
		{
			$this->pass();
		}
	}
	
	function testDefaultOutput()
	{
		$field = new ListRadios('foo', array('bar', 'baz'));
		$this->assertEqual($field->output(), '<ul><li class="field optional radio"><input id="f_foo_bar" name="foo" type="radio" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="field optional radio"><input id="f_foo_baz" name="foo" type="radio" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
	}
	
	function testParargraphOutput()
	{
		$field = new ListRadios('foo', array('bar', 'baz'));
		$this->assertEqual($field->__toString(), '<div class="field list radio-list"><h3>Foo</h3><ul><li class="field optional radio"><input id="f_foo_bar" name="foo" type="radio" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="field optional radio"><input id="f_foo_baz" name="foo" type="radio" value="baz" /><label for="f_foo_baz">Baz</label></li></ul></div>');
	}
	
	function testRequiredRadios()
	{
		try
		{
			$field = new ListRadios('foo');
			$this->fail('Exception was expected.');
		}
		catch (Exception\MissingArgument $e)
		{
			$this->pass();
		}
		
		try
		{
			$field = new ListRadios('foo', array());
			$this->fail('Exception was expected.');
		}
		catch (Exception\MissingArgument $e)
		{
			$this->pass();
		}
	}
	
	function testSetValue()
	{
		$field = new ListRadios('foo', array('bar', 'baz'));
		$field->value = 'bar';
		$this->assertEqual($field->output(), '<ul><li class="field optional radio"><input checked="checked" id="f_foo_bar" name="foo" type="radio" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="field optional radio"><input id="f_foo_baz" name="foo" type="radio" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
		
		$field->value = 'baz';
		$this->assertEqual($field->output(), '<ul><li class="field optional radio"><input id="f_foo_bar" name="foo" type="radio" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="field optional radio"><input checked="checked" id="f_foo_baz" name="foo" type="radio" value="baz" /><label for="f_foo_baz">Baz</label></li></ul>');
	}
	
	function testValidation()
	{
		$field = new ListRadios('foo', array('bar', 'baz'));
		$field->value = 'foobar';
		$this->assertFalse($field->isValid());
	}	
}

/**
 * {@link \Pancake\Field\ListRadios} unit tests for "other field"
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class ListRadiosOtherFieldTest extends Test
{
	function testAsCheckbox()
	{
		$field = new ListRadios('foo', array('bar', 'other'));
		$this->assertEqual($field->output(), '<ul><li class="field optional radio"><input id="f_foo_bar" name="foo" type="radio" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="field optional radio"><input id="f_foo_other" name="foo" type="radio" value="other" /><label for="f_foo_other_text">Other:</label><input id="f_foo_other_text" name="foo_other_text" type="text" /></li></ul>');
	}
	
	function testBackwardsCompatibility()
	{
		$field = new ListRadios('foo', array('bar', '{other}'));
		$this->assertEqual($field->output(), '<ul><li class="field optional radio"><input id="f_foo_bar" name="foo" type="radio" value="bar" /><label for="f_foo_bar">Bar</label></li><li class="field optional radio"><input id="f_foo_other" name="foo" type="radio" value="other" /><label for="f_foo_other_text">Other:</label><input id="f_foo_other_text" name="foo_other_text" type="text" /></li></ul>');
	}
	
	function testFormattedValue()
	{
		$field = new ListRadios('foo', array('bar', 'other'));
		$_POST['foo_other_text'] = 'Ja';
		$field->value = 'other';
		
		$this->assertEqual($field->formattedValue, 'Other (Ja)');
		
		unset($_POST);
		
		$field = new ListRadios('foo', array('bar', 'other'));
		$field->value = 'other';
		
		$this->assertEqual($field->formattedValue, 'Other');
	}
	
	function testValidation()
	{
		$field = new ListRadios('foo', array('bar', 'other'));
		$_POST['foo_other_text'] = 'ja';
		$field->value = 'other';
		
		$this->assertTrue($field->isValid());
		
		unset($_POST);
	}
}