<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\ListRanking;

/**
 * {@link \Pancake\Field\ListRanking} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class ListRankingTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\ListRanking'));
		$this->assertEqual('Pancake\Field\FieldList', get_parent_class('\Pancake\Field\ListRanking'));
		$this->assertEqual(ListRanking::$methodName, 'ranking');
	}
	
	function testCustomTextInput()
	{
		$field = new ListRanking('foo', array(array('bar', array('class' => 'foobar')), 'baz'));
		$this->assertEqual($field->__toString(), '<div class="field list ranking"><h3>Foo</h3><ul><li class="field text"><input class="foobar" id="f_foo_bar" name="foo_bar" type="text" /><label for="f_foo_bar">Bar</label></li><li class="field text"><input id="f_foo_baz" name="foo_baz" type="text" /><label for="f_foo_baz">Baz</label></li></ul></div>');
	}
	
	function testFormattedValue()
	{
		$field = new ListRanking('foo', array(array('baz', array('value' => '2')), array('bar', array('value' => '1'))));
		$this->assertEqual($field->formattedValue, 'Bar (1), Baz (2)');
	}
	
	function testOutput()
	{
		$field = new ListRanking('foo', array('bar', 'baz'));
		$this->assertEqual($field->__toString(), '<div class="field list ranking"><h3>Foo</h3><ul><li class="field text"><input id="f_foo_bar" name="foo_bar" type="text" /><label for="f_foo_bar">Bar</label></li><li class="field text"><input id="f_foo_baz" name="foo_baz" type="text" /><label for="f_foo_baz">Baz</label></li></ul></div>');
	}
	
	function testRankLimits()
	{
		$field = new ListRanking('foo', array(array('bar', array('value' => '1')), 'baz'), array('rank_up_to' => 1));
		$this->assertTrue($field->isValid());
	}
	
	function testValidation()
	{
		$field = new ListRanking('foo', array(array('bar', array('value' => '1')), array('baz', array('value' => '2'))));
		$this->assertTrue($field->isValid());
		
		$field = new ListRanking('foo', array(array('bar', array('value' => '1')), array('baz', array('value' => '1'))));
		$this->assertFalse($field->isValid());
		
		$field = new ListRanking('foo', array(array('bar', array('value' => '1')), array('baz', array('value' => '3'))));
		$this->assertFalse($field->isValid());
		
		$field = new ListRanking('foo', array(array('bar', array('value' => '1')), array('baz', array('value' => '3')), 'foo'));
		$this->assertFalse($field->isValid());
	}
}