<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\Phone;

/**
 * {@link \Pancake\Field\Phone} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class PhoneTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('Pancake\Field\Phone'));
		$this->assertEqual('Pancake\Field\InputText', get_parent_class('Pancake\Field\Phone'));
		$this->assertEqual(Phone::$methodName, 'phone');
	}
	
	function testDefaultOutput()
	{
		$field = new Phone('foobar');
		$this->assertEqual($field->output(), '<input id="f_foobar" maxlength="20" name="foobar" type="text" />');
	}
	
	function testFormattedValue()
	{
		$field = new Phone('foobar');
		
		$field->value = '13215015718';
		$this->assertEqual($field->formattedValue, '(321)501-5718');
	}
	
	function testParagraphOutput()
	{
		$field = new Phone('foobar');
		$this->assertEqual($field->__toString(), '<p class="field phone text"><label for="f_foobar">Foobar</label><input id="f_foobar" maxlength="20" name="foobar" type="text" /></p>');
	}
	
	function testValidation()
	{
		$field = new Phone('foobar');
		
		$field->value = '13215015718';
		$this->assertTrue($field->isValid());
		
		$field->value = '1547';
		$this->assertFalse($field->isValid());
	}	
}