<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\Select;

/**
 * {@link \Pancake\Field\Select} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class SelectTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\Select'));
		$this->assertEqual('Pancake\Field\FieldList', get_parent_class('Pancake\Field\Select'));
		$this->assertEqual(Select::$methodName, 'select');
	}
	
	function testDefaultOutput()
	{
		$field = new Select('foo', array('bar', 'baz'));
		$this->assertEqual($field->output(), '<select id="f_foo" name="foo"><option></option><option value="bar">Bar</option><option value="baz">Baz</option></select>');
	}
	
	function testFormattedValue()
	{
		$field = new Select('foo', array('bar', 'baz'));
		
		$this->assertEqual($field->formattedValue, '');
		
		$field->value = 'bar';
		$this->assertEqual($field->formattedValue, 'Bar');
	}
	
	function testMultiSelect()
	{
		$field = new Select('foo', array('foo', 'bar', 'baz'), array('multiple' => 'multiple'));
		$this->assertEqual($field->output(), '<select id="f_foo" multiple="multiple" name="foo[]"><option value="foo">Foo</option><option value="bar">Bar</option><option value="baz">Baz</option></select>');
	}
	
	function testMultiSelectFormattedValue()
	{
		$field = new Select('foo', array('foo', 'bar', 'baz'), array('multiple' => 'multiple'));
		
		$field->value = array('bar', 'baz');
		$this->assertEqual($field->formattedValue, 'Bar, Baz');
	}
	
	function testNoBlankOption()
	{
		$field = new Select('foo', array('bar', 'baz'), array('include_blank' => false));
		$this->assertEqual($field->output(), '<select id="f_foo" name="foo"><option value="bar">Bar</option><option value="baz">Baz</option></select>');
	}
	
	function testRequiredOptions()
	{
		try
		{
			$field = new Select('foo');
			$this->fail('Exception was expected.');
		}
		catch (Exception\MissingArgument $e)
		{
			$this->pass();
		}
		
		try
		{
			$field = new Select('foo', array());
			$this->fail('Exception was expected.');
		}
		catch (Exception\MissingArgument $e)
		{
			$this->pass();
		}
	}
	
	function testParargraphOutput()
	{
		$field = new Select('foo', array('bar', 'baz'));
		$this->assertEqual($field->__toString(), '<p class="field select"><label for="f_foo">Foo</label><select id="f_foo" name="foo"><option></option><option value="bar">Bar</option><option value="baz">Baz</option></select></p>');
	}
	
	function testSetValue()
	{
		$field = new Select('foo', array('bar', 'baz'));
		$field->value = 'bar';
		$this->assertEqual($field->output(), '<select id="f_foo" name="foo"><option></option><option selected="selected" value="bar">Bar</option><option value="baz">Baz</option></select>');
		
		$field->value = 'baz';
		$this->assertEqual($field->output(), '<select id="f_foo" name="foo"><option></option><option value="bar">Bar</option><option selected="selected" value="baz">Baz</option></select>');
	}
	
	function testValidation()
	{
		$field = new Select('foo', array('bar', 'baz'));
		$field->value = 'foobar';
		$this->assertFalse($field->isValid());
	}
}