<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Field\Textarea;

/**
 * {@link \Pancake\Field\Textarea} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class TextareaTest extends Test
{
	function test()
	{
		$this->assertTrue(class_exists('\Pancake\Field\Textarea'));
		$this->assertEqual('Pancake\Field\Field', get_parent_class('Pancake\Field\Textarea'));
		$this->assertEqual(Textarea::$methodName, 'textarea');
	}
	
	function testAttributes()
	{
		$field = new Textarea('foobar', 10, 20, array('class' => 'baz'));
		$this->assertEqual($field->output(), '<textarea class="baz" cols="10" id="f_foobar" name="foobar" rows="20"></textarea>');
	}
	
	function testBasicOutput()
	{
		$field = new Textarea('foobar', 10, 20);
		$this->assertEqual($field->output(), '<textarea cols="10" id="f_foobar" name="foobar" rows="20"></textarea>');
	}
	
	function testNoRowsAndNoCols()
	{
		try
		{
			$field = new Textarea('foobar');
			$this->fail('An exception was expected.');
		}
		catch (Exception\MissingArgument $e)
		{
			$this->pass();
		}
	}
	
	function testParagraphClasses()
	{
		$field = new Textarea('foobar', 10, 20);
		$this->assertEqual($field->__toString(), '<p class="field textarea"><label for="f_foobar">Foobar</label><textarea cols="10" id="f_foobar" name="foobar" rows="20"></textarea></p>');
	}
	
	function testSpamLinks()
	{
		$field = new Textarea('foobar', 10, 20);
		$field->value = 'http://www.google.com
		http://www.google.com
		http://www.yahoo.com
		http://www.google.com
		http://umn.edu
		http://www.microsoft.com
		http://www.google.com
		http://www.google.com
		http://www.google.com
		http://www.google.com
		http://www.google.com
		http://facebook.com
		http://www.google.com
		http://www.google.com
		http://www.google.com
		http://spamwebsite.ru
		http://www.google.com
		http://www.google.ru
		http://www.google.se
		http://www.google.com
		http://sua.umn.edu
		http://www.google.com
		http://www.google.com
		http://www.google.com
		http://www.google.com
		http://dn.se
		http://www.google.com
		http://www.google.com
		http://www.news.com
		http://www.google.com';
		$this->assertFalse($field->isValid());
	}
	
	function testValue()
	{
		$field = new Textarea('foobar', 10, 20, array('class' => 'baz', 'value' => 'hejsan'));
		$this->assertEqual($field->output(), '<textarea class="baz" cols="10" id="f_foobar" name="foobar" rows="20">hejsan</textarea>');
	}
}