<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Helper\Attributes;

/**
 * {@link \Pancake\Helper\Attributes} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class AttributesTest extends Test
{
	function test()
	{
		$attributes = array('ze' => 'bra', 'foo' => 'bar', 'hej' => 'san');
		$this->assertEqual(Attributes::process($attributes), ' foo="bar" hej="san" ze="bra"');
	}
	
	function testDefaultAttributes()
	{
		$defaults = array('ze' => 'ze', 'foo' => 'foo', 'hej' => 'hej');
		$attributes = array('ze' => 'bra', 'foo' => 'bar');
		$this->assertEqual(Attributes::process($attributes, $defaults), ' foo="bar" hej="hej" ze="bra"');
		$this->assertEqual(Attributes::process(array(), $defaults), ' foo="foo" hej="hej" ze="ze"');
	}
	
	function testNotAssociatedArrays()
	{
		$attributes = array('ze' => 'bra', 'foo' => 'bar', 'hej');
		
		try
		{
			Attributes::process($attributes);
			$this->fail('An exception was expected.');
		}
		catch (Exception\ValueError $e)
		{
			$this->pass();
		}
	}
	
	function testUnsafeHTML()
	{
		$attributes = array('ze' => '<bar>', 'foo' => 'bar', 'hej' => 'san');
		$this->assertEqual(Attributes::process($attributes), ' foo="bar" hej="san" ze="&lt;bar&gt;"');
	}
	
	function testValidAttributes()
	{
		$defaults = array('ze' => 'ze', 'foo' => 'foo', 'hej' => 'hej');
		$attributes = array('ze' => 'bra', 'foo' => 'bar', 'bar' => 'foo');
		$valid = array('ze', 'foo', 'hej');
		
		try
		{
			Attributes::process($attributes, $defaults, $valid);
			$this->fail('An exception was expected.');
		}
		catch (Exception\Exception $e)
		{
			$this->pass();
		}
	}
}