<?php
/**
 * Pancake Forms
 * 
 * @author  Ethan Poole
 * @package Pancake
 */

namespace Pancake\Test;

use Pancake\Exception;
use Pancake\Hook;

/**
 * {@link \Pancake\Hook\Hook} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class HookTest extends Test
{
	function testExists()
	{
		$this->assertTrue(class_exists('\Pancake\Hook\Hook'));
	}
	
	function testFail()
	{
		$hook = new FailHook;
		$this->assertFalse($hook->run(array()));
	}
}

/**
 * {@link \Pancake\Hook\Hook::addHook()} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class HookAddTest extends Test
{
	function test()
	{
		$this->assertIsA($this->_pancake->addHook('after', 'EmailForm', array('to' => 'pool0079@umn.edu')), 'boolean');
	}
	
	function testInvalid()
	{
		try
		{
			$this->_pancake->addHook('after', 'foobar');
			$this->fail('Exception excepted.');
		}
		catch (Exception\DoesNotExist $e)
		{
			$this->pass();
		}
	}
	
	function testInvalidType()
	{
		try
		{
			$this->_pancake->addHook('foobar', 'EmailForm');
			$this->fail('Exception excepted.');
		}
		catch (Exception\Exception $e)
		{
			$this->pass();
		}
	}
	
	function testWithParameters()
	{
		$this->assertIsA($this->_pancake->addHook('after', 'EmailForm', array('to' => 'pool0079@umn.edu', 'from' => 'test')), 'boolean');
	}
}

/**
 * {@link \Pancake\Hook\Hook::__construct()} unit tests
 * 
 * @package    Pancake
 * @subpackage Tests
 */
class HookSettingsTest extends Test
{
	function test()
	{
		$hook = new TestHook(array('foo' => 'baz'));
	}
	
	function testInvalidSettings()
	{
		try
		{
			$hook = new TestHook(array('hej' => 'san'));
			$this->fail('Exception expected');
		}
		catch (Exception\Exception $e)
		{
			$this->pass();
		}
	}
	
	function testMissingSettings()
	{
		try
		{
			$hook = new TestHook(array('bar' => 'baz'));
			$this->fail('Exception expected');
		}
		catch (Exception\Exception $e)
		{
			$this->pass();
		}
	}
}

/* STUFF FOR TESTING */
	/**
	 * @package    Pancake
	 * @subpackage Tests
	 */
	class TestHook extends Hook\Hook
	{
		protected $_validSettings = array('foo' => null, 'bar' => null);
		protected $_requiredSettings = array('foo');
		
		function run($fields) { return 'kiitos'; }
	}
	
	/**
	 * @package    Pancake
	 * @subpackage Tests
	 */
	class FailHook extends Hook\Hook
	{
		function run($fields) { return false; }
	}
/* END STUFF FOR TESTING */